@@ -1,6 +1,6 @@
 /*
     This file is part of the KContacts framework.
-    Copyright (c) 2015-2016 Laurent Montel <montel@kde.org>
+    Copyright (c) 2015-2017 Laurent Montel <montel@kde.org>
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Library General Public
@@ -27,7 +27,7 @@ class ResourceLocatorUrlTest : public QObject
 {
     Q_OBJECT
 public:
-    explicit ResourceLocatorUrlTest(QObject *parent = Q_NULLPTR);
+    explicit ResourceLocatorUrlTest(QObject *parent = nullptr);
     ~ResourceLocatorUrlTest();
 
 private Q_SLOTS:
