@@ -1,14 +1,27 @@
 /*
     This file is part of the KContacts framework.
-    SPDX-FileCopyrightText: 2016 David Faure <faure@kde.org>
+    Copyright (c) 2016 David Faure <faure@kde.org>
 
-    SPDX-License-Identifier: LGPL-2.0-or-later
+    This library is free software; you can redistribute it and/or
+    modify it under the terms of the GNU Library General Public
+    License as published by the Free Software Foundation; either
+    version 2 of the License, or (at your option) any later version.
+
+    This library is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+    Library General Public License for more details.
+
+    You should have received a copy of the GNU Library General Public License
+    along with this library; see the file COPYING.LIB.  If not, write to
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 */
 
 #include "vcardtool_benchmark.h"
 #include "title.h"
-#include "vcardtool_p.h"
-#include <QTest>
+#include "vcardtool.h"
+#include <qtest.h>
 
 PerformanceTest::PerformanceTest(QObject *parent)
     : QObject(parent)
