@@ -1,6 +1,6 @@
 /*
     This file is part of the KContacts framework.
-    Copyright (c) 2015-2016 Laurent Montel <montel@kde.org>
+    Copyright (c) 2015-2017 Laurent Montel <montel@kde.org>
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Library General Public
@@ -117,16 +117,16 @@ CalendarUrl &CalendarUrl::operator=(const CalendarUrl &other)
 
 QString CalendarUrl::toString() const
 {
-    QString str;
-    str += QLatin1String("CalendarUrl {\n");
+    QString str = QLatin1String("CalendarUrl {\n");
     str += QStringLiteral("    url: %1\n").arg(d->url.toString());
     str += QStringLiteral("    type: %1\n").arg(CalendarUrl::Private::typeToString(d->type));
     if (!d->parameters.isEmpty()) {
-        QMapIterator<QString, QStringList> i(d->parameters);
+        QMap<QString, QStringList>::const_iterator it = d->parameters.constBegin();
+        const QMap<QString, QStringList>::const_iterator end = d->parameters.constEnd();
         QString param;
-        while (i.hasNext()) {
-            i.next();
-            param += QStringLiteral("%1 %2").arg(i.key(), i.value().join(QLatin1Char(',')));
+        while (it != end) {
+            param += QStringLiteral("%1 %2").arg(it.key(), it.value().join(QLatin1Char(',')));
+            ++it;
         }
         str += QStringLiteral("    parameters: %1\n").arg(param);
     }
