@@ -1,16 +1,29 @@
 /*
-    This file is part of the KContacts framework.
-    SPDX-FileCopyrightText: 2008 Tobias Koenig <tokoe@kde.org>
+  This file is part of the KContacts framework.
+  Copyright (c) 2008 Tobias Koenig <tokoe@kde.org>
 
-    SPDX-License-Identifier: LGPL-2.0-or-later
+  This library is free software; you can redistribute it and/or
+  modify it under the terms of the GNU Library General Public
+  License as published by the Free Software Foundation; either
+  version 2 of the License, or (at your option) any later version.
+
+  This library is distributed in the hope that it will be useful,
+  but WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+  Library General Public License for more details.
+
+  You should have received a copy of the GNU Library General Public License
+  along with this library; see the file COPYING.LIB.  If not, write to
+  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+  Boston, MA 02110-1301, USA.
 */
 
 #ifndef KCONTACTS_CONTACTGROUP_H
 #define KCONTACTS_CONTACTGROUP_H
 
-#include <QList>
-#include <QMetaType>
+#include <QVector>
 #include <QSharedDataPointer>
+#include <QMetaType>
 
 #include "kcontacts_export.h"
 
@@ -18,12 +31,9 @@ class QString;
 
 namespace KContacts
 {
-/*!
- * \class KContacts::ContactGroup
- * \inheaderfile KContacts/ContactGroup
- * \inmodule KContacts
- *
- * \brief This class represents a group of contacts.
+
+/**
+ * @short This class represents a group of contacts.
  *
  * It can contain two types of contacts, either a reference
  * or data.
@@ -31,200 +41,189 @@ namespace KContacts
  * identifies the real contact in the system.
  * The data entry contains a name and an email address.
  *
- * \since 4.3
+ * @author Tobias Koenig <tokoe@kde.org>
+ * @since 4.3
  */
 class KCONTACTS_EXPORT ContactGroup
 {
 public:
-    /*!
-     * \class KContacts::ContactGroup::ContactReference
-     * \inheaderfile KContacts/ContactGroup
-     * \inmodule KContacts
-     *
+
+    /**
      * This class represents a contact reference
      */
     class KCONTACTS_EXPORT ContactReference
     {
     public:
-        /*!
+        /**
          * A list of contact references.
          */
-        typedef QList<ContactReference> List;
+        typedef QVector<ContactReference> List;
 
-        /*!
+        /**
          * Creates an empty contact reference.
          */
         ContactReference();
 
-        /*!
-         * Creates a contact reference from an \a other reference.
+        /**
+         * Creates a contact reference from an @p other reference.
          */
         ContactReference(const ContactReference &other);
 
-        /*!
-         * Creates a contact reference for the given contact \a uid.
+        /**
+         * Creates a contact reference for the given contact @p uid.
          */
         ContactReference(const QString &uid);
 
-        /*!
+        /**
          * Destroys the contact reference.
          */
         ~ContactReference();
 
-        /*!
+        /**
          * Sets the contact uid of the contact reference.
-         *
-         * \a uid identifier of the contact to reference
-         *
-         * \note That is the Akonadi Item ID of the contact that
+         * @param uid identifier of the contact to reference
+         * @note That is the Akonadi Item ID of the contact that
          *       is referenced here.
          */
         void setUid(const QString &uid);
 
-        /*!
+        /**
          * Returns the contact uid of the contact reference.
          *
-         * \note That is the Akonadi Item ID of the contact that
+         * @note That is the Akonadi Item ID of the contact that
          *       is referenced here.
          */
-        [[nodiscard]] QString uid() const;
+        QString uid() const;
 
-        /*!
+        /**
          * Sets the contact gid of the contact reference.
-         *
-         * \a gid globally unique identifier of the contact to reference
-         * \since 4.12
+         * @param gid globally unique identifier of the contact to reference
+         * @since 4.12
          */
         void setGid(const QString &gid);
 
-        /*!
+        /**
          * Returns the contact GID of the contact reference.
-         * \since 4.12
+         * @since 4.12
          */
-        [[nodiscard]] QString gid() const;
+        QString gid() const;
 
-        /*!
+        /**
          * Sets the preferred email address.
          */
         void setPreferredEmail(const QString &email);
 
-        /*!
+        /**
          * Returns the preferred email address, or an empty string
          * if no preferred email address is set.
          */
-        [[nodiscard]] QString preferredEmail() const;
+        QString preferredEmail() const;
 
-        /*!
+        /**
          * Inserts a custom entry.
-         * If an entry with the same \a key already exists, it is
+         * If an entry with the same @p key already exists, it is
          * overwritten.
          *
-         * \a key The unique key.
-         *
-         * \a value The value.
+         * @param key The unique key.
+         * @param value The value.
          */
         void insertCustom(const QString &key, const QString &value);
 
-        /*!
-         * Removes the custom entry with the given \a key.
+        /**
+         * Removes the custom entry with the given @p key.
          */
         void removeCustom(const QString &key);
 
-        /*!
-         * Returns the value for the given \a key, or an empty string
+        /**
+         * Returns the value for the given @p key, or an empty string
          * if the entry for that key does not exists.
          */
-        [[nodiscard]] QString custom(const QString &key) const;
+        QString custom(const QString &key) const;
 
-        /*!
-         * \internal
+        /**
+         * @internal
          */
         ContactReference &operator=(const ContactReference &other);
 
-        /*!
-         * \internal
+        /**
+         * @internal
          */
-        [[nodiscard]] bool operator==(const ContactReference &other) const;
+        bool operator==(const ContactReference &other) const;
 
     private:
         class ContactReferencePrivate;
         QSharedDataPointer<ContactReferencePrivate> d;
     };
 
-    /*!
-     * \class KContacts::ContactGroup::ContactGroupReference
-     * \inheaderfile KContacts/ContactGroup
-     * \inmodule KContacts
-     *
-     * \brief This class represents a contact group reference.
+    /**
+     * This class represents a contact group reference
      */
     class KCONTACTS_EXPORT ContactGroupReference
     {
     public:
-        /*!
+        /**
          * A list of contact group references.
          */
-        typedef QList<ContactGroupReference> List;
+        typedef QVector<ContactGroupReference> List;
 
-        /*!
+        /**
          * Creates an empty contact group reference.
          */
         ContactGroupReference();
 
-        /*!
-         * Creates a contact group reference from an \a other reference.
+        /**
+         * Creates a contact group reference from an @p other reference.
          */
         ContactGroupReference(const ContactGroupReference &other);
 
-        /*!
-         * Creates a contact group reference for the given contact group \a uid.
+        /**
+         * Creates a contact group reference for the given contact group @p uid.
          */
         ContactGroupReference(const QString &uid);
 
-        /*!
+        /**
          * Destroys the contact group reference.
          */
         ~ContactGroupReference();
 
-        /*!
+        /**
          * Sets the contact group uid of the contact group reference.
          */
         void setUid(const QString &uid);
 
-        /*!
+        /**
          * Returns the contact group uid of the contact group reference.
          */
         QString uid() const;
 
-        /*!
+        /**
          * Inserts a custom entry.
-         * If an entry with the same \a key already exists, it is
+         * If an entry with the same @p key already exists, it is
          * overwritten.
          *
-         * \a key The unique key.
-         *
-         * \a value The value.
+         * @param key The unique key.
+         * @param value The value.
          */
         void insertCustom(const QString &key, const QString &value);
 
-        /*!
-         * Removes the custom entry with the given \a key.
+        /**
+         * Removes the custom entry with the given @p key.
          */
         void removeCustom(const QString &key);
 
-        /*!
-         * Returns the value for the given \a key, or an empty string
+        /**
+         * Returns the value for the given @p key, or an empty string
          * if the entry for that key does not exists.
          */
         QString custom(const QString &key) const;
 
-        /*!
-         * \internal
+        /**
+         * @internal
          */
         ContactGroupReference &operator=(const ContactGroupReference &other);
 
-        /*!
-         * \internal
+        /**
+         * @internal
          */
         bool operator==(const ContactGroupReference &other) const;
 
@@ -233,250 +232,245 @@ public:
         QSharedDataPointer<ContactGroupReferencePrivate> d;
     };
 
-    /*!
-     * \class KContacts::ContactGroup::Data
-     * \inheaderfile KContacts/ContactGroup
-     * \inmodule KContacts
-     *
+    /**
      * This class represents a contact data object
      */
     class KCONTACTS_EXPORT Data
     {
     public:
-        /*!
+        /**
          * A list of contact data.
          */
-        typedef QList<Data> List;
+        typedef QVector<Data> List;
 
-        /*!
+        /**
          * Creates an empty contact data object.
          */
         Data();
 
-        /*!
-         * Creates a contact data object from an \a other data object.
+        /**
+         * Creates a contact data object from an @p other data object.
          */
         Data(const Data &other);
 
-        /*!
-         * Creates a contact data object with the given \a name and \a email address.
+        /**
+         * Creates a contact data object with the given @p name and @p email address.
          */
         Data(const QString &name, const QString &email);
 
-        /*!
+        /**
          * Destroys the contact data object.
          */
         ~Data();
 
-        /*!
-         * Sets the \a name of the contact data object.
+        /**
+         * Sets the @p name of the contact data object.
          */
         void setName(const QString &name);
 
-        /*!
+        /**
          * Returns the name of the contact data object.
          */
-        [[nodiscard]] QString name() const;
+        QString name() const;
 
-        /*!
-         * Sets the \a email address of the contact data object.
+        /**
+         * Sets the @p email address of the contact data object.
          */
         void setEmail(const QString &email);
 
-        /*!
+        /**
          * Returns the email address of the contact data object.
          */
-        [[nodiscard]] QString email() const;
+        QString email() const;
 
-        /*!
+        /**
          * Inserts a custom entry.
-         * If an entry with the same \a key already exists, it is
+         * If an entry with the same @p key already exists, it is
          * overwritten.
          *
-         * \a key The unique key.
-         *
-         * \a value The value.
+         * @param key The unique key.
+         * @param value The value.
          */
         void insertCustom(const QString &key, const QString &value);
 
-        /*!
-         * Removes the custom entry with the given \a key.
+        /**
+         * Removes the custom entry with the given @p key.
          */
         void removeCustom(const QString &key);
 
-        /*!
-         * Returns the value for the given \a key, or an empty string
+        /**
+         * Returns the value for the given @p key, or an empty string
          * if the entry for that key does not exists.
          */
-        [[nodiscard]] QString custom(const QString &key) const;
+        QString custom(const QString &key) const;
 
-        /*!
-         * \internal
+        /**
+         * @internal
          */
         Data &operator=(const Data &other);
 
-        /*!
-         * \internal
+        /**
+         * @internal
          */
-        [[nodiscard]] bool operator==(const Data &other) const;
+        bool operator==(const Data &other) const;
 
     private:
         class DataPrivate;
         QSharedDataPointer<DataPrivate> d;
     };
 
-    /*!
+    /**
      * A list of contact groups.
      */
-    typedef QList<ContactGroup> List;
+    typedef QVector<ContactGroup> List;
 
-    /*!
+    /**
      * Creates an empty contact group.
      */
     ContactGroup();
 
-    /*!
-     * Creates a contact group from an \a other group.
+    /**
+     * Creates a contact group from an @p other group.
      */
     ContactGroup(const ContactGroup &other);
 
-    /*!
+    /**
      * Creates a contact group with the given name.
      */
     ContactGroup(const QString &name);
 
-    /*!
+    /**
      * Destroys the contact group.
      */
     ~ContactGroup();
 
-    /*!
-     * Sets the unique \a id of the contact group.
+    /**
+     * Sets the unique @p id of the contact group.
      */
     void setId(const QString &id);
 
-    /*!
+    /**
      * Returns the unique id of the contact group.
      */
-    [[nodiscard]] QString id() const;
+    QString id() const;
 
-    /*!
-     * Sets the i18n'd \a name of the contact group.
+    /**
+     * Sets the i18n'd @p name of the contact group.
      */
     void setName(const QString &name);
 
-    /*!
+    /**
      * Returns the i18n'd name of the contact group.
      */
-    [[nodiscard]] QString name() const;
+    QString name() const;
 
-    /*!
+    /**
      * Returns the number of contacts in this group.
      * That includes the contact references and contact data.
      */
-    [[nodiscard]] int count() const;
+    unsigned int count() const;
 
-    /*!
+    /**
      * Returns the number of contact references in this group.
      */
-    [[nodiscard]] int contactReferenceCount() const;
+    unsigned int contactReferenceCount() const;
 
-    /*!
+    /**
      * Returns the number of group references in this group.
      */
-    [[nodiscard]] int contactGroupReferenceCount() const;
+    unsigned int contactGroupReferenceCount() const;
 
-    /*!
+    /**
      * Returns the number of contact data objects in this group.
      */
-    [[nodiscard]] int dataCount() const;
+    unsigned int dataCount() const;
 
-    /*!
-     * Returns the contact reference at the given \a index.
+    /**
+     * Returns the contact reference at the given @p index.
      */
-    [[nodiscard]] ContactReference &contactReference(int index);
+    ContactReference &contactReference(unsigned int index);
 
-    /*!
-     * Returns the contact reference at the given \a index.
+    /**
+     * Returns the contact reference at the given @p index.
      */
-    const ContactReference &contactReference(int index) const;
+    const ContactReference &contactReference(unsigned int index) const;
 
-    /*!
-     * Returns the contact group reference at the given \a index.
+    /**
+     * Returns the contact group reference at the given @p index.
      */
-    ContactGroupReference &contactGroupReference(int index);
+    ContactGroupReference &contactGroupReference(unsigned int index);
 
-    /*!
-     * Returns the contact group reference at the given \a index.
+    /**
+     * Returns the contact group reference at the given @p index.
      */
-    const ContactGroupReference &contactGroupReference(int index) const;
+    const ContactGroupReference &contactGroupReference(unsigned int index) const;
 
-    /*!
-     * Returns the contact data object at the given \a index.
+    /**
+     * Returns the contact data object at the given @p index.
      */
-    Data &data(int index);
+    Data &data(unsigned int index);
 
-    /*!
-     * Returns the contact data object at the given \a index.
+    /**
+     * Returns the contact data object at the given @p index.
      */
-    const Data &data(int index) const;
+    const Data &data(unsigned int index) const;
 
-    /*!
-     * Appends a new contact \a reference to the contact group.
+    /**
+     * Appends a new contact @p reference to the contact group.
      */
     void append(const ContactReference &reference);
 
-    /*!
-     * Appends a new contact group \a reference to the contact group.
+    /**
+     * Appends a new contact group @p reference to the contact group.
      */
     void append(const ContactGroupReference &reference);
 
-    /*!
-     * Appends a new contact \a data object to the contact group.
+    /**
+     * Appends a new contact @p data object to the contact group.
      */
     void append(const Data &data);
 
-    /*!
-     * Removes the given contact \a reference from the contact group.
+    /**
+     * Removes the given contact @p reference from the contact group.
      */
     void remove(const ContactReference &reference);
 
-    /*!
-     * Removes the given contact group \a reference from the contact group.
+    /**
+     * Removes the given contact group @p reference from the contact group.
      */
     void remove(const ContactGroupReference &reference);
 
-    /*!
-     * Removes the given contact \a data object from the contact group.
+    /**
+     * Removes the given contact @p data object from the contact group.
      */
     void remove(const Data &data);
 
-    /*!
+    /**
      * Removes all contact references from the contact group.
      */
     void removeAllContactReferences();
 
-    /*!
+    /**
      * Removes all contact group references from the contact group.
      */
     void removeAllContactGroupReferences();
 
-    /*!
+    /**
      * Removes all contact data from the contact group.
      */
     void removeAllContactData();
 
-    /*!
-     * \internal
+    /**
+     * @internal
      */
     ContactGroup &operator=(const ContactGroup &other);
 
-    /*!
-     * \internal
+    /**
+     * @internal
      */
-    [[nodiscard]] bool operator==(const ContactGroup &other) const;
+    bool operator==(const ContactGroup &other) const;
 
-    /*!
+    /**
      * Returns the MIME type used for Contact Groups
      */
     static QString mimeType();
@@ -485,9 +479,10 @@ private:
     class Private;
     QSharedDataPointer<Private> d;
 };
+
 }
-Q_DECLARE_TYPEINFO(KContacts::ContactGroup::ContactGroupReference, Q_RELOCATABLE_TYPE);
-Q_DECLARE_TYPEINFO(KContacts::ContactGroup::ContactReference, Q_RELOCATABLE_TYPE);
+Q_DECLARE_TYPEINFO(KContacts::ContactGroup::ContactGroupReference, Q_MOVABLE_TYPE);
+Q_DECLARE_TYPEINFO(KContacts::ContactGroup::ContactReference, Q_MOVABLE_TYPE);
 
 #define KCONTACTS_CONTACTGROUP_METATYPE_DEFINED
 Q_DECLARE_METATYPE(KContacts::ContactGroup)
