@@ -1,6 +1,6 @@
 /*
     This file is part of the KContacts framework.
-    Copyright (c) 2016 Laurent Montel <montel@kde.org>
+    Copyright (C) 2016-2017 Laurent Montel <montel@kde.org>
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Library General Public
@@ -111,15 +111,15 @@ Note &Note::operator=(const Note &other)
 
 QString Note::toString() const
 {
-    QString str;
-    str += QLatin1String("Note {\n");
+    QString str = QLatin1String("Note {\n");
     str += QStringLiteral("    note: %1\n").arg(d->note);
     if (!d->parameters.isEmpty()) {
-        QMapIterator<QString, QStringList> i(d->parameters);
         QString param;
-        while (i.hasNext()) {
-            i.next();
-            param += QStringLiteral("%1 %2").arg(i.key(), i.value().join(QLatin1Char(',')));
+        QMap<QString, QStringList>::const_iterator it = d->parameters.constBegin();
+        const QMap<QString, QStringList>::const_iterator end = d->parameters.constEnd();
+        while (it != end) {
+            param += QStringLiteral("%1 %2").arg(it.key(), it.value().join(QLatin1Char(',')));
+            ++it;
         }
         str += QStringLiteral("    parameters: %1\n").arg(param);
     }
