@@ -22,8 +22,8 @@
 
 #include <klocalizedstring.h>
 
-#include <QtCore/QDataStream>
-#include <QtCore/QSharedData>
+#include <QDataStream>
+#include <QSharedData>
 
 using namespace KContacts;
 
