@@ -42,6 +42,7 @@ VCardLine::VCardLine(const VCardLine &line)
     mParamMap = line.mParamMap;
     mValue = line.mValue;
     mIdentifier = line.mIdentifier;
+    mGroup = line.mGroup;
 }
 
 VCardLine::~VCardLine()
@@ -57,10 +58,19 @@ VCardLine &VCardLine::operator=(const VCardLine &line)
     mParamMap = line.mParamMap;
     mValue = line.mValue;
     mIdentifier = line.mIdentifier;
+    mGroup = line.mGroup;
 
     return *this;
 }
 
+bool VCardLine::operator==(const VCardLine &other) const
+{
+    return (mParamMap == other.parameterMap()) &&
+           (mValue == other.value()) &&
+           (mIdentifier == other.identifier()) &&
+           (mGroup == other.group());
+}
+
 void VCardLine::setIdentifier(const QString &identifier)
 {
     mIdentifier = identifier;
